@@ -2,10 +2,12 @@ from typing import Awaitable, Callable, List, TYPE_CHECKING, Union
 
 from rich.segment import Segment
 
-from textual._typing import Protocol
+from ._typing import Protocol
+
 
 if TYPE_CHECKING:
     from .message import Message
+    from .strip import Strip
 
 
 class MessageTarget(Protocol):
@@ -27,5 +29,5 @@ class EventTarget(Protocol):
         ...
 
 
-Lines = List[List[Segment]]
+SegmentLines = List[List["Segment"]]
 CallbackType = Union[Callable[[], Awaitable[None]], Callable[[], None]]
